#!/bin/bash

cat <<EOF
Maxthon currently supported distros:
  Ubuntu (12.04 LTS)
  Fedora (19)
  Linux Deepin (2013)
when you try to install on other distros, make sure your glibc version is greater than 2.15.
You can ask for help at:
http://forum.maxthon.com/forum.php?mod=forumdisplay&fid=38&filter=typeid&typeid=39
Or
http://bbs.maxthon.cn/forum.php?mod=forumdisplay&fid=157&filter=typeid&typeid=260
EOF

if [ "$(id -u)" != "0" ]; then
    echo "please use sudo to install maxthon"
    exit 0
fi

cp -vf ../maxthon /opt/

#设置sandbox系统权限
chown root:root /opt/maxthon/maxthon_sandbox
chmod 4755 /opt/maxthon/maxthon_sandbox

# 注册系统图标资源
XDG_ICON_RESOURCE="`which xdg-icon-resource 2> /dev/null`"
if [ ! -x "$XDG_ICON_RESOURCE" ]; then
  echo "Error: Could not find xdg-icon-resource" >&2
  exit 1
fi
for icon in "/opt/maxthon/product_logo_"*.png; do
  size="${icon##*/product_logo_}"
  "$XDG_ICON_RESOURCE" install --size "${size%.png}" "$icon" "maxthon-browser"
done

# Add an entry to the system menu
XDG_DESKTOP_MENU="`which xdg-desktop-menu 2> /dev/null`"
UPDATE_MENUS="`which update-menus 2> /dev/null`"
if [ ! -x "$XDG_DESKTOP_MENU" ]; then
  echo "Error: Could not find xdg-desktop-menu" >&2
  exit 1
fi

"$XDG_DESKTOP_MENU"  install --novendor /opt/maxthon/maxthon.desktop

if [ -x "$UPDATE_MENUS" ]; then
  update-menus
fi


#设置动态库路径
DEFAULT_ARCH="i386"

get_lib_dir() {
  if [ "$DEFAULT_ARCH" = "i386" ]; then
    LIBDIR=lib/i386-linux-gnu
  elif [ "$DEFAULT_ARCH" = "amd64" ]; then
    LIBDIR=lib/x86_64-linux-gnu
  else
    echo Unknown CPU Architecture: "$DEFAULT_ARCH"
    exit 1
  fi
  if [[ ! -d $LIBDIR ]]; then
    if [ "$DEFAULT_ARCH" = "i386" ]; then
      LIBDIR=lib
    elif [ "$DEFAULT_ARCH" = "amd64" ]; then
      LIBDIR=lib64
    fi
  fi
}

#设置udev动态库文件位置
# Fedora 18 now has libudev.so.1. http://crbug.com/145160
# Same for Ubuntu 13.04. http://crbug.com/226002
LIBUDEV_0=libudev.so.0
LIBUDEV_1=libudev.so.1

add_udev_symlinks() {
  get_lib_dir
  if [ -f "/$LIBDIR/$LIBUDEV_0" -o -f "/usr/$LIBDIR/$LIBUDEV_0" -o -f "/lib/$LIBUDEV_0" ]; then
    return 0
  fi

  if [ -f "/$LIBDIR/$LIBUDEV_1" ]; then
    ln -sf "/$LIBDIR/$LIBUDEV_1" "/opt/maxthon/$LIBUDEV_0"
  elif [ -f "/usr/$LIBDIR/$LIBUDEV_1" ]; then
    ln -sf "/usr/$LIBDIR/$LIBUDEV_1" "/opt/maxthon/$LIBUDEV_0"
  else
    echo "$LIBUDEV_1" not found in "$LIBDIR" or "/usr/$LIBDIR".
    exit 1
  fi
}

remove_udev_symlinks() {
  rm -rf "/opt/maxthon/$LIBUDEV_0"
}

remove_udev_symlinks
add_udev_symlinks

mkdir -p /etc/default/maxthon.d/
if [ ! -f /etc/default/maxthon.d/pn ]; then
  cp -f /opt/maxthon/conf.d/pn /etc/default/maxthon.d/pn
fi
ln -svf /opt/maxthon/maxthon-browser /usr/bin/maxthon
#install report
STAT_REPORT='/opt/maxthon/report'
[[ -x $STAT_REPORT]] && nohup $STAT_REPORT inst &
cat <<EOF
  Just run "maxthon" to surf on the web :)
EOF
exit 0